# Gongge

九宫格图片分割，最简单的Python图像分割工具。


## 特点

- 默认九宫格分割模式
  - 支持自定义设置分割数量
- 支持分割图像预览
- 默认保存到本地文件夹，包括预览图像

## 安装说明

```Python
pip install Gongge
```

## 调用说明

默认生成九格

```Python
import Gongge

Gongge.split("test.jpg")
```

![](https://python123.io/api/v1/files/HJ-7cswpc/test-9.jpg)

设置参数size修改生成格数

```Python
import Gongge

Gongge.split("test.jpg", size=2)
```

![](https://python123.io/api/v1/files/B1Xg5sP69/test-4.jpg)


## 效果展示


![](https://python123.io/api/v1/files/Bk-NqoDTc/test-16.jpg)

![](https://python123.io/api/v1/files/BJ7VcoP6c/test-25.jpg)

![](https://python123.io/api/v1/files/BySEqsPpc/test-36.jpg)

![](https://python123.io/api/v1/files/r1w45iDaq/test-49.jpg)

![](https://python123.io/api/v1/files/BydEcsPT9/test-64.jpg)